//@ sourceURL=wisej.web.Widget.startup.js

/**
 * Initializes the widget.
 *
 * This function is called when the InitScript property of
 * wisej.web.Widget changes.
 *
 * 'this' refers to the container which is a wisej.web.Widget instance.
 *
 * 'this.container' refers to the DOM element and can be used to initialize
 * the third party javascript widget.
 *
 * @param options {Map} Options map (optional).
 */
this.init = function(options) {

    // your initialization code.
    this.map = new ol.Map({
        layers: [
        new ol.layer.Vector({
            renderMode: 'image',
            source: new ol.source.Vector({
              url: 'https://openlayers.org/en/v3.20.1/examples/data/geojson/countries.geojson',
              format: new ol.format.GeoJSON()
            }),
            style: new ol.style.Style({
                fill: new ol.style.Fill({
                  color: 'rgba(255, 255, 255, 0.6)'
                }),
                stroke: new ol.style.Stroke({
                  color: '#319FD3',
                  width: 1
                })
            })
        })
        ],
        target: this.container,
        view: new ol.View({
          center: [0, 0],
          zoom: 1
        })
    });

    var highlight;
    var map = this.map;
  
    var featureOverlay = new ol.layer.Vector({
        source: new ol.source.Vector(),
        map: this.map,
        style: new ol.style.Style({
          stroke: new ol.style.Stroke({
            color: '#f00',
            width: 1
          }),
            fill: new ol.style.Fill({
            color: 'rgba(255,0,0,0.1)'
          })
        })
    });

    var displayFeatureInfo = function(pixel) {
        var feature = map.forEachFeatureAtPixel(pixel, function(feature) {
            return feature;
        });
        if (feature !== highlight) {
          if (highlight) {
            featureOverlay.getSource().removeFeature(highlight);
          }
          if (feature) {
            featureOverlay.getSource().addFeature(feature);
          }
          highlight = feature;
        }
    };

    map.on('pointermove', function(evt) {
       if (evt.dragging) {
           return;
       }
       var pixel = map.getEventPixel(evt.originalEvent);

       displayFeatureInfo(pixel);
    });
   
    this.addListener("resize", function() { this.map.updateSize();});
}
/**
 * Updates the widget when the options object changes.
 *
 * @param options {Map} Options map (optional).
 * @param old {Map} Previous options map (optional).
 */
this.update = function(options, old) {

    // your update code.

}
